Documentation
¶
Overview ¶
Package flyweight is an example of the Flyweight Pattern.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ConcreteFlyweight ¶
type ConcreteFlyweight struct {
// contains filtered or unexported fields
}
ConcreteFlyweight implements a Flyweighter interface.
type FlyweightFactory ¶
type FlyweightFactory struct {
// contains filtered or unexported fields
}
FlyweightFactory implements a factory. If a suitable flyweighter is in pool, then returns it.
func (*FlyweightFactory) GetFlyweight ¶
func (f *FlyweightFactory) GetFlyweight(filename string) Flyweighter
GetFlyweight creates or returns a suitable Flyweighter by state.
type Flyweighter ¶
Flyweighter interface
Click to show internal directories.
Click to hide internal directories.