Documentation
¶
Overview ¶
Package template_method is an example of the Template Method Pattern. In fact, this pattern is based on Abstract Class and Polymorphism. But there’s nothing like that in Go, so the composition will be applied.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FrenchQuotes ¶
type FrenchQuotes struct {
}
FrenchQuotes implements wrapping the string in French quotes.
type GermanQuotes ¶
type GermanQuotes struct {
}
GermanQuotes implements wrapping the string in German quotes.
type QuotesInterface ¶
QuotesInterface provides an interface for setting different quotes.
Click to show internal directories.
Click to hide internal directories.